AFFILIATE_KEY = ""  # see http://acestream.net/affiliate/index.php#profile-page
ZONE_ID = ""  # ID of board, see http://acestream.net/affiliate/index.php#zone-page
XML_API_URL = "http://torrentstream.net/api/xml"
